package com.steering.mes.mcp.entity;

import java.io.Serializable;
import java.sql.Date;

/**
 * 热处理实绩
 * @author lzh 2015-7-27
 *
 */
public class HeatTreatmentResult implements Serializable {
	/** VersionUID */
    private static final long serialVersionUID = 1L;
    /** 计划号 */
    private String planNo;
    /** 产线代码 */
    private String plineCode;
    /** 操作班次 */
    private String colShft;
    /** 操作班组 */
    private String colGroup;
    /** 操作人 */
    private String colUser;
    /** 录入时间 */
    private String colTime;
    /** 监制人 */
    private String producer;
    /** 到场时间 */
    private String producerTime;
    
    //高温炉（淬火炉）
    /** 装炉时间 */
    private String  hHeatEnterTime;
    /** 出炉时间 */
    private String  hHeatOutTime;
    /** 出口温度 */
    private String  hHeatExitTemp;
    /** 节拍 */
    private String  hHeatTaktTime;
    /** 均热一区平均温度 */
    private String  hHeatAvgTemp1;
    /** 均热二区平均温度*/
    private String hHeatAvgTemp2;
    /** 均热三区平均温度 */
    private String hHeatAvgTemp3;
    /** 加热一区平均温度 */
    private String hHeatAvgTemp4;
    /** 加热二区平均温度 */
    private String hHeatAvgTemp5;
    /** 加热三区平均温度 */
    private String hHeatAvgTemp6;
    /** 淬火方式 */
    private String  hHeatQuenchMode;
    /** 流量 */
    private String  hHeatQuenchFlow;
    /** 淬火时间 */
    private String  hHeatQuenchSecs;
    
    //低温炉（回火炉）
    /** 装炉时间 */
    private String lHeatEnterTime;
    /** 出炉时间 */
    private String lHeatOutTime;
    /** 出口温度 */
    private String lHeatExitTemp;
    /** 节拍 */
    private String lHeatTaktTime;
    /** 均热一区平均温度 */
    private String lHeatAvgTemp1;
    /** 均热二区平均温度*/
    private String lHeatAvgTemp2;
    /** 均热三区平均温度 */
    private String lHeatAvgTemp3;
    /** 加热一区平均温度 */
    private String lHeatAvgTemp4;
    /** 加热二区平均温度 */
    private String lHeatAvgTemp5;
    /** 加热三区平均温度 */
    private String lHeatAvgTemp6;
    /** 加热四区平均温度 */
    private String lHeatAvgTemp7;
    /** 加热五区平均温度 */
    private String lHeatAvgTemp8;
    /** 加热六区平均温度 */
    private String lHeatAvgTemp9;
    
	public String getPlanNo() {
		return planNo;
	}
	public void setPlanNo(String planNo) {
		this.planNo = planNo;
	}
	public String getPlineCode() {
		return plineCode;
	}
	public void setPlineCode(String plineCode) {
		this.plineCode = plineCode;
	}
	public String getColShft() {
		return colShft;
	}
	public void setColShft(String colShft) {
		this.colShft = colShft;
	}
	public String getColGroup() {
		return colGroup;
	}
	public void setColGroup(String colGroup) {
		this.colGroup = colGroup;
	}
	public String getColUser() {
		return colUser;
	}
	public void setColUser(String colUser) {
		this.colUser = colUser;
	}
	public String getColTime() {
		return colTime;
	}
	public void setColTime(String colTime) {
		this.colTime = colTime;
	}
	public String getProducer() {
		return producer;
	}
	public void setProducer(String producer) {
		this.producer = producer;
	}
	
	
	public String gethHeatExitTemp() {
		return hHeatExitTemp;
	}
	public void sethHeatExitTemp(String hHeatExitTemp) {
		this.hHeatExitTemp = hHeatExitTemp;
	}
	public String gethHeatTaktTime() {
		return hHeatTaktTime;
	}
	public void sethHeatTaktTime(String hHeatTaktTime) {
		this.hHeatTaktTime = hHeatTaktTime;
	}
	public String gethHeatAvgTemp1() {
		return hHeatAvgTemp1;
	}
	public void sethHeatAvgTemp1(String hHeatAvgTemp1) {
		this.hHeatAvgTemp1 = hHeatAvgTemp1;
	}
	public String gethHeatAvgTemp2() {
		return hHeatAvgTemp2;
	}
	public void sethHeatAvgTemp2(String hHeatAvgTemp2) {
		this.hHeatAvgTemp2 = hHeatAvgTemp2;
	}
	public String gethHeatAvgTemp3() {
		return hHeatAvgTemp3;
	}
	public void sethHeatAvgTemp3(String hHeatAvgTemp3) {
		this.hHeatAvgTemp3 = hHeatAvgTemp3;
	}
	public String gethHeatAvgTemp4() {
		return hHeatAvgTemp4;
	}
	public void sethHeatAvgTemp4(String hHeatAvgTemp4) {
		this.hHeatAvgTemp4 = hHeatAvgTemp4;
	}
	public String gethHeatAvgTemp5() {
		return hHeatAvgTemp5;
	}
	public void sethHeatAvgTemp5(String hHeatAvgTemp5) {
		this.hHeatAvgTemp5 = hHeatAvgTemp5;
	}
	public String gethHeatAvgTemp6() {
		return hHeatAvgTemp6;
	}
	public void sethHeatAvgTemp6(String hHeatAvgTemp6) {
		this.hHeatAvgTemp6 = hHeatAvgTemp6;
	}
	public String gethHeatQuenchMode() {
		return hHeatQuenchMode;
	}
	public void sethHeatQuenchMode(String hHeatQuenchMode) {
		this.hHeatQuenchMode = hHeatQuenchMode;
	}
	public String gethHeatQuenchFlow() {
		return hHeatQuenchFlow;
	}
	public void sethHeatQuenchFlow(String hHeatQuenchFlow) {
		this.hHeatQuenchFlow = hHeatQuenchFlow;
	}
	public String gethHeatQuenchSecs() {
		return hHeatQuenchSecs;
	}
	public void sethHeatQuenchSecs(String hHeatQuenchSecs) {
		this.hHeatQuenchSecs = hHeatQuenchSecs;
	}
	
	
	
	public String getProducerTime() {
		return producerTime;
	}
	public void setProducerTime(String producerTime) {
		this.producerTime = producerTime;
	}
	public String gethHeatEnterTime() {
		return hHeatEnterTime;
	}
	public void sethHeatEnterTime(String hHeatEnterTime) {
		this.hHeatEnterTime = hHeatEnterTime;
	}
	public String gethHeatOutTime() {
		return hHeatOutTime;
	}
	public void sethHeatOutTime(String hHeatOutTime) {
		this.hHeatOutTime = hHeatOutTime;
	}
	public String getlHeatEnterTime() {
		return lHeatEnterTime;
	}
	public void setlHeatEnterTime(String lHeatEnterTime) {
		this.lHeatEnterTime = lHeatEnterTime;
	}
	public String getlHeatOutTime() {
		return lHeatOutTime;
	}
	public void setlHeatOutTime(String lHeatOutTime) {
		this.lHeatOutTime = lHeatOutTime;
	}
	public String getlHeatExitTemp() {
		return lHeatExitTemp;
	}
	public void setlHeatExitTemp(String lHeatExitTemp) {
		this.lHeatExitTemp = lHeatExitTemp;
	}
	public String getlHeatTaktTime() {
		return lHeatTaktTime;
	}
	public void setlHeatTaktTime(String lHeatTaktTime) {
		this.lHeatTaktTime = lHeatTaktTime;
	}
	public String getlHeatAvgTemp1() {
		return lHeatAvgTemp1;
	}
	public void setlHeatAvgTemp1(String lHeatAvgTemp1) {
		this.lHeatAvgTemp1 = lHeatAvgTemp1;
	}
	public String getlHeatAvgTemp2() {
		return lHeatAvgTemp2;
	}
	public void setlHeatAvgTemp2(String lHeatAvgTemp2) {
		this.lHeatAvgTemp2 = lHeatAvgTemp2;
	}
	public String getlHeatAvgTemp3() {
		return lHeatAvgTemp3;
	}
	public void setlHeatAvgTemp3(String lHeatAvgTemp3) {
		this.lHeatAvgTemp3 = lHeatAvgTemp3;
	}
	public String getlHeatAvgTemp4() {
		return lHeatAvgTemp4;
	}
	public void setlHeatAvgTemp4(String lHeatAvgTemp4) {
		this.lHeatAvgTemp4 = lHeatAvgTemp4;
	}
	public String getlHeatAvgTemp5() {
		return lHeatAvgTemp5;
	}
	public void setlHeatAvgTemp5(String lHeatAvgTemp5) {
		this.lHeatAvgTemp5 = lHeatAvgTemp5;
	}
	public String getlHeatAvgTemp6() {
		return lHeatAvgTemp6;
	}
	public void setlHeatAvgTemp6(String lHeatAvgTemp6) {
		this.lHeatAvgTemp6 = lHeatAvgTemp6;
	}
	public String getlHeatAvgTemp7() {
		return lHeatAvgTemp7;
	}
	public void setlHeatAvgTemp7(String lHeatAvgTemp7) {
		this.lHeatAvgTemp7 = lHeatAvgTemp7;
	}
	public String getlHeatAvgTemp8() {
		return lHeatAvgTemp8;
	}
	public void setlHeatAvgTemp8(String lHeatAvgTemp8) {
		this.lHeatAvgTemp8 = lHeatAvgTemp8;
	}
	public String getlHeatAvgTemp9() {
		return lHeatAvgTemp9;
	}
	public void setlHeatAvgTemp9(String lHeatAvgTemp9) {
		this.lHeatAvgTemp9 = lHeatAvgTemp9;
	}
	public static long getSerialversionuid() {
		return serialVersionUID;
	}
    
}
